package org.imageclef.flickr;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.LinkedList;
import java.util.zip.GZIPInputStream;

public class FileReader {
	
	public static String ReadTextString(File file) {
		BufferedReader reader;
		try { reader = new BufferedReader(new InputStreamReader(new FileInputStream(file))); }
		catch (IOException e) {
			System.err.println("ERROR: could not open " + file.getPath());
			return null;
		}
		StringBuilder sb = new StringBuilder();
		try {
			do {
				String s = reader.readLine();
				if (s == null)
					break;
				sb.append(s);
				sb.append("\n");
			} while (true);
		} catch (IOException e) {
			System.err.println("ERROR: could not read from " + file.getPath());
			e.printStackTrace();
			return null;
		}
		finally {
			try { reader.close(); }
			catch (IOException e) {
				System.err.println("ERROR: could not close " + file.getPath());
				e.printStackTrace();
				return null;
			}
		}
		return sb.toString();
	}
	
	public static LinkedList<String> ReadTextLines(File file) {
		BufferedReader reader;
		try { reader = new BufferedReader(new InputStreamReader(new FileInputStream(file))); }
		catch (IOException e) {
			System.err.println("ERROR: could not open " + file.getPath());
			return null;
		}
		LinkedList<String> lines = new LinkedList<String>();
		try {
			do {
				String s = reader.readLine();
				if (s == null)
					break;
				lines.add(s); // note: this may be an empty line
			} while (true);
		} catch (IOException e) {
			System.err.println("ERROR: could not read from " + file.getPath());
			e.printStackTrace();
			return null;
		}
		finally {
			try { reader.close(); }
			catch (IOException e) {
				System.err.println("ERROR: could not close " + file.getPath());
				e.printStackTrace();
				return null;
			}
		}
		return lines;
	}
	
	public static String ReadGzipString(File file) {
		BufferedReader reader;
		try {
			reader = new BufferedReader(new InputStreamReader(new GZIPInputStream(new FileInputStream(file))));
		}
		catch (IOException e) {
			System.err.println("ERROR: could not open " + file.getPath());
			return null;
		}
		StringBuilder sb = new StringBuilder();
		try {
			do {
				String s = reader.readLine();
				if (s == null)
					break;
				sb.append(s);
				sb.append("\n");
			} while (true);
		} catch (IOException e) {
			System.err.println("ERROR: could not read from " + file.getPath());
			e.printStackTrace();
			return null;
		}
		finally {
			try { reader.close(); }
			catch (IOException e) {
				System.err.println("ERROR: could not close " + file.getPath());
				e.printStackTrace();
				return null;
			}
		}
		return sb.toString();
	}
	
	public static LinkedList<String> ReadGzipLines(File file) {
		BufferedReader reader;
		try {
			reader = new BufferedReader(new InputStreamReader(new GZIPInputStream(new FileInputStream(file))));
		}
		catch (IOException e) {
			System.err.println("ERROR: could not open " + file.getPath());
			return null;
		}
		LinkedList<String> lines = new LinkedList<String>();
		try {
			do {
				String s = reader.readLine();
				if (s == null)
					break;
				lines.add(s); // note: this may be an empty line
			} while (true);
		} catch (IOException e) {
			System.err.println("ERROR: could not read from " + file.getPath());
			e.printStackTrace();
			return null;
		}
		finally {
			try { reader.close(); }
			catch (IOException e) {
				System.err.println("ERROR: could not close " + file.getPath());
				e.printStackTrace();
				return null;
			}
		}
		return lines;
	}
}
